You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by rg...@apache.org on 2015/07/08 15:50:18 UTC

svn commit: r1689876 [5/6] - in /qpid/java/trunk: bdbstore/src/main/java/org/apache/qpid/server/store/berkeleydb/upgrade/ broker-plugins/amqp-0-8-protocol/src/main/java/org/apache/qpid/server/protocol/v0_8/ broker-plugins/amqp-0-8-protocol/src/test/jav...

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class BasicRecoverBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -86,7 +86,7 @@ public class BasicRecoverBody extends AM
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchBasicRecover(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class BasicRecoverSyncBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -89,7 +89,7 @@ public class BasicRecoverSyncBody extend
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchBasicRecoverSync(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRecoverSyncOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class BasicRecoverSyncOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -74,7 +74,7 @@ public class BasicRecoverSyncOkBody exte
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchBasicRecoverSyncOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRejectBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRejectBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRejectBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicRejectBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class BasicRejectBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -95,7 +95,7 @@ public class BasicRejectBody extends AMQ
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchBasicReject(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicReturnBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicReturnBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicReturnBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/BasicReturnBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class BasicReturnBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -111,7 +111,7 @@ public class BasicReturnBody extends AMQ
         writeAMQShortString( buffer, _routingKey );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchBasicReturn(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelAlertBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelAlertBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelAlertBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelAlertBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelAlertBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -101,7 +101,7 @@ public class ChannelAlertBody extends AM
         writeFieldTable( buffer, _details );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
     return dispatcher.dispatchChannelAlert(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelCloseBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -109,7 +109,7 @@ public class ChannelCloseBody extends AM
         writeUnsignedShort( buffer, _methodId );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelClose(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelCloseOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelCloseOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -71,7 +71,7 @@ public class ChannelCloseOkBody extends
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelCloseOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelFlowBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -78,7 +78,7 @@ public class ChannelFlowBody extends AMQ
         writeBitfield( buffer, _active ? (byte)1 : (byte)0);
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelFlow(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelFlowOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelFlowOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -79,7 +79,7 @@ public class ChannelFlowOkBody extends A
         writeBitfield( buffer, _active ? (byte)1 : (byte)0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelFlowOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelOpenBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -72,7 +72,7 @@ public class ChannelOpenBody extends AMQ
         writeAMQShortString( buffer, null );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelOpen(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ChannelOpenOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ChannelOpenOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -86,7 +86,7 @@ public class ChannelOpenOkBody extends A
         }
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchChannelOpenOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ClientMethodDispatcher.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ClientMethodDispatcher.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ClientMethodDispatcher.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ClientMethodDispatcher.java Wed Jul  8 13:50:16 2015
@@ -29,49 +29,50 @@
 
 package org.apache.qpid.framing;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public interface ClientMethodDispatcher
 {
 
-    public boolean dispatchBasicCancelOk(BasicCancelOkBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicConsumeOk(BasicConsumeOkBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicDeliver(BasicDeliverBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicGetEmpty(BasicGetEmptyBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicGetOk(BasicGetOkBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicQosOk(BasicQosOkBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicReturn(BasicReturnBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelClose(ChannelCloseBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelCloseOk(ChannelCloseOkBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelFlow(ChannelFlowBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelFlowOk(ChannelFlowOkBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelOpenOk(ChannelOpenOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionClose(ConnectionCloseBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionCloseOk(ConnectionCloseOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionOpenOk(ConnectionOpenOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionSecure(ConnectionSecureBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionStart(ConnectionStartBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionTune(ConnectionTuneBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeBoundOk(ExchangeBoundOkBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeDeclareOk(ExchangeDeclareOkBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeDeleteOk(ExchangeDeleteOkBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueBindOk(QueueBindOkBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueDeclareOk(QueueDeclareOkBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueDeleteOk(QueueDeleteOkBody body, int channelId) throws AMQException;
-    public boolean dispatchQueuePurgeOk(QueuePurgeOkBody body, int channelId) throws AMQException;
-    public boolean dispatchTxCommitOk(TxCommitOkBody body, int channelId) throws AMQException;
-    public boolean dispatchTxRollbackOk(TxRollbackOkBody body, int channelId) throws AMQException;
-    public boolean dispatchTxSelectOk(TxSelectOkBody body, int channelId) throws AMQException;
+    public boolean dispatchBasicCancelOk(BasicCancelOkBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicConsumeOk(BasicConsumeOkBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicDeliver(BasicDeliverBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicGetEmpty(BasicGetEmptyBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicGetOk(BasicGetOkBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicQosOk(BasicQosOkBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicReturn(BasicReturnBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelClose(ChannelCloseBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelCloseOk(ChannelCloseOkBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelFlow(ChannelFlowBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelFlowOk(ChannelFlowOkBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelOpenOk(ChannelOpenOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionClose(ConnectionCloseBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionCloseOk(ConnectionCloseOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionOpenOk(ConnectionOpenOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionSecure(ConnectionSecureBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionStart(ConnectionStartBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionTune(ConnectionTuneBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeBoundOk(ExchangeBoundOkBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeDeclareOk(ExchangeDeclareOkBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeDeleteOk(ExchangeDeleteOkBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueBindOk(QueueBindOkBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueDeclareOk(QueueDeclareOkBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueDeleteOk(QueueDeleteOkBody body, int channelId) throws QpidException;
+    public boolean dispatchQueuePurgeOk(QueuePurgeOkBody body, int channelId) throws QpidException;
+    public boolean dispatchTxCommitOk(TxCommitOkBody body, int channelId) throws QpidException;
+    public boolean dispatchTxRollbackOk(TxRollbackOkBody body, int channelId) throws QpidException;
+    public boolean dispatchTxSelectOk(TxSelectOkBody body, int channelId) throws QpidException;
+
+    boolean dispatchConnectionRedirect(ConnectionRedirectBody connectionRedirectBody, int channelId) throws
+                                                                                                     QpidException;
+    boolean dispatchAccessRequestOk(AccessRequestOkBody accessRequestOkBody, int channelId) throws QpidException;
 
-    boolean dispatchConnectionRedirect(ConnectionRedirectBody connectionRedirectBody, int channelId) throws AMQException;
-    boolean dispatchAccessRequestOk(AccessRequestOkBody accessRequestOkBody, int channelId) throws AMQException;
-
-    boolean dispatchQueueUnbindOk(QueueUnbindOkBody queueUnbindOkBody, int channelId) throws AMQException;
+    boolean dispatchQueueUnbindOk(QueueUnbindOkBody queueUnbindOkBody, int channelId) throws QpidException;
 
     boolean dispatchBasicRecoverSyncOk(BasicRecoverSyncOkBody basicRecoverSyncOkBody, int channelId)
-            throws AMQException;
+            throws QpidException;
 
-    boolean dispatchChannelAlert(ChannelAlertBody channelAlertBody, int channelId) throws AMQException;
+    boolean dispatchChannelAlert(ChannelAlertBody channelAlertBody, int channelId) throws QpidException;
 
-    boolean dispatchConfirmSelectOk(ConfirmSelectOkBody confirmSelectOkBody, int channelId) throws AMQException;
+    boolean dispatchConfirmSelectOk(ConfirmSelectOkBody confirmSelectOkBody, int channelId) throws QpidException;
 }

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConfirmSelectBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -78,7 +78,7 @@ public class ConfirmSelectBody extends A
         writeBitfield( buffer, _nowait ? (byte)1 : (byte)0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConfirmSelect(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConfirmSelectOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class ConfirmSelectOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -64,7 +64,7 @@ public class ConfirmSelectOkBody extends
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConfirmSelectOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionCloseBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -111,7 +111,7 @@ public class ConnectionCloseBody extends
         writeUnsignedShort( buffer, _methodId );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
     return dispatcher.dispatchConnectionClose(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionCloseOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class ConnectionCloseOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -68,7 +68,7 @@ public class ConnectionCloseOkBody exten
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionCloseOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionOpenBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -101,7 +101,7 @@ public class ConnectionOpenBody extends
         writeBitfield( buffer, _insist ? (byte)1 : (byte)0);
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionOpen(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionOpenOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionOpenOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -82,7 +82,7 @@ public class ConnectionOpenOkBody extend
         writeAMQShortString( buffer, _knownHosts );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionOpenOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionRedirectBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionRedirectBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionRedirectBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionRedirectBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionRedirectBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -91,7 +91,7 @@ public class ConnectionRedirectBody exte
         writeAMQShortString( buffer, _knownHosts );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionRedirect(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionSecureBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -82,7 +82,7 @@ public class ConnectionSecureBody extend
         writeBytes( buffer, _challenge );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionSecure(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionSecureOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionSecureOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -82,7 +82,7 @@ public class ConnectionSecureOkBody exte
         writeBytes( buffer, _response );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionSecureOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionStartBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -110,7 +110,7 @@ public class ConnectionStartBody extends
         writeBytes( buffer, _locales );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionStart(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionStartOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionStartOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -103,7 +103,7 @@ public class ConnectionStartOkBody exten
         writeAMQShortString( buffer, _locale );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionStartOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionTuneBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -99,7 +99,7 @@ public class ConnectionTuneBody extends
         writeUnsignedShort( buffer, _heartbeat );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionTune(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ConnectionTuneOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ConnectionTuneOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -99,7 +99,7 @@ public class ConnectionTuneOkBody extend
         writeUnsignedShort( buffer, _heartbeat );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchConnectionTuneOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentBody.java Wed Jul  8 13:50:16 2015
@@ -25,7 +25,7 @@ import java.io.DataOutput;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 import org.apache.qpid.protocol.AMQVersionAwareProtocolSession;
 import org.apache.qpid.transport.ByteBufferSender;
@@ -68,7 +68,7 @@ public class ContentBody implements AMQB
     }
 
     public void handle(final int channelId, final AMQVersionAwareProtocolSession session)
-            throws AMQException
+            throws QpidException
     {
         session.contentBodyReceived(channelId, this);
     }
@@ -166,7 +166,7 @@ public class ContentBody implements AMQB
             return _length;
         }
 
-        public void handle(int channelId, AMQVersionAwareProtocolSession amqProtocolSession) throws AMQException
+        public void handle(int channelId, AMQVersionAwareProtocolSession amqProtocolSession) throws QpidException
         {
             throw new RuntimeException("Buffered Body only to be used for outgoing data");
         }

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderBody.java Wed Jul  8 13:50:16 2015
@@ -26,8 +26,9 @@ import java.io.DataOutput;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
+import org.apache.qpid.protocol.AMQConstant;
 import org.apache.qpid.protocol.AMQVersionAwareProtocolSession;
 import org.apache.qpid.transport.ByteBufferSender;
 import org.apache.qpid.util.BytesDataOutput;
@@ -115,7 +116,7 @@ public class ContentHeaderBody implement
     }
 
     public void handle(final int channelId, final AMQVersionAwareProtocolSession session)
-            throws AMQException
+            throws QpidException
     {
         session.contentHeaderReceived(channelId, this);
     }
@@ -185,7 +186,7 @@ public class ContentHeaderBody implement
 
         if (classId != CLASS_ID)
         {
-            throw new AMQFrameDecodingException(null, "Unsupported content header class id: " + classId, null);
+            throw new AMQFrameDecodingException(AMQConstant.FRAME_ERROR, "Unsupported content header class id: " + classId, null);
         }
         properties = new BasicContentHeaderProperties();
         properties.populatePropertiesFromBuffer(buffer, propertyFlags, (int)(size-14));

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderPropertiesFactory.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderPropertiesFactory.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderPropertiesFactory.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ContentHeaderPropertiesFactory.java Wed Jul  8 13:50:16 2015
@@ -23,6 +23,8 @@ package org.apache.qpid.framing;
 import java.io.DataInput;
 import java.io.IOException;
 
+import org.apache.qpid.protocol.AMQConstant;
+
 public class ContentHeaderPropertiesFactory
 {
     private static final ContentHeaderPropertiesFactory _instance = new ContentHeaderPropertiesFactory();
@@ -50,7 +52,7 @@ public class ContentHeaderPropertiesFact
         }
         else
         {
-        	throw new AMQFrameDecodingException(null, "Unsupport content header class id: " + classId, null);
+        	throw new AMQFrameDecodingException(AMQConstant.FRAME_ERROR, "Unsupport content header class id: " + classId, null);
         }
         properties.populatePropertiesFromBuffer(buffer, propertyFlags, size);
         return properties;

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeBoundBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -102,7 +102,7 @@ public class ExchangeBoundBody extends A
         writeAMQShortString( buffer, _queue );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeBound(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeBoundOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeBoundOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -98,7 +98,7 @@ public class ExchangeBoundOkBody extends
         writeAMQShortString( buffer, _replyText );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeBoundOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeDeclareBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -166,7 +166,7 @@ public class ExchangeDeclareBody extends
         writeFieldTable( buffer, _arguments );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeDeclare(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeclareOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeDeclareOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -72,7 +72,7 @@ public class ExchangeDeclareOkBody exten
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeDeclareOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeDeleteBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -115,7 +115,7 @@ public class ExchangeDeleteBody extends
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeDelete(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ExchangeDeleteOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class ExchangeDeleteOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -72,7 +72,7 @@ public class ExchangeDeleteOkBody extend
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchExchangeDeleteOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/HeartbeatBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/HeartbeatBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/HeartbeatBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/HeartbeatBody.java Wed Jul  8 13:50:16 2015
@@ -24,7 +24,7 @@ import java.io.DataInputStream;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 import org.apache.qpid.protocol.AMQVersionAwareProtocolSession;
 import org.apache.qpid.transport.ByteBufferSender;
@@ -69,7 +69,7 @@ public class HeartbeatBody implements AM
     }
 
     public void handle(final int channelId, final AMQVersionAwareProtocolSession session)
-            throws AMQException
+            throws QpidException
     {
         session.heartbeatBodyReceived(channelId, this);
     }

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ProtocolInitiation.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ProtocolInitiation.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ProtocolInitiation.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ProtocolInitiation.java Wed Jul  8 13:50:16 2015
@@ -27,7 +27,7 @@ import java.nio.ByteBuffer;
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 import org.apache.qpid.transport.ByteBufferSender;
 import org.apache.qpid.util.BytesDataOutput;
@@ -160,7 +160,7 @@ public class ProtocolInitiation extends
 
     }
 
-    public ProtocolVersion checkVersion() throws AMQException
+    public ProtocolVersion checkVersion() throws QpidException
     {
 
         if(_protocolHeader.length != 4)

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueBindBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -136,7 +136,7 @@ public class QueueBindBody extends AMQMe
         writeFieldTable( buffer, _arguments );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueBind(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueBindOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueBindOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -72,7 +72,7 @@ public class QueueBindOkBody extends AMQ
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueBindOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueDeclareBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -156,7 +156,7 @@ public class QueueDeclareBody extends AM
         writeFieldTable( buffer, _arguments );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueDeclare(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeclareOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueDeclareOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -100,7 +100,7 @@ public class QueueDeclareOkBody extends
         writeUnsignedInteger( buffer, _consumerCount );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueDeclareOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueDeleteBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -125,7 +125,7 @@ public class QueueDeleteBody extends AMQ
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueDelete(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueDeleteOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueDeleteOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -81,7 +81,7 @@ public class QueueDeleteOkBody extends A
         writeUnsignedInteger( buffer, _messageCount );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueDeleteOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueuePurgeBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -105,7 +105,7 @@ public class QueuePurgeBody extends AMQM
         writeBitfield( buffer, _bitfield0 );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueuePurge(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueuePurgeOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueuePurgeOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -81,7 +81,7 @@ public class QueuePurgeOkBody extends AM
         writeUnsignedInteger( buffer, _messageCount );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueuePurgeOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueUnbindBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -121,7 +121,7 @@ public class QueueUnbindBody extends AMQ
         writeFieldTable( buffer, _arguments );
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchQueueUnbind(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/QueueUnbindOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.codec.MarkableDataInput;
 
 public class QueueUnbindOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
@@ -72,7 +72,7 @@ public class QueueUnbindOkBody extends A
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
     return dispatcher.dispatchQueueUnbindOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ServerMethodDispatcher.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ServerMethodDispatcher.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ServerMethodDispatcher.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/ServerMethodDispatcher.java Wed Jul  8 13:50:16 2015
@@ -29,45 +29,45 @@
 
 package org.apache.qpid.framing;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public interface ServerMethodDispatcher
 {
-    boolean dispatchAccessRequest(AccessRequestBody accessRequestBody, int channelId) throws AMQException;
+    boolean dispatchAccessRequest(AccessRequestBody accessRequestBody, int channelId) throws QpidException;
 
-    public boolean dispatchBasicAck(BasicAckBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicCancel(BasicCancelBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicConsume(BasicConsumeBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicGet(BasicGetBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicPublish(BasicPublishBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicQos(BasicQosBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicRecover(BasicRecoverBody body, int channelId) throws AMQException;
-    public boolean dispatchBasicReject(BasicRejectBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelClose(ChannelCloseBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelCloseOk(ChannelCloseOkBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelFlow(ChannelFlowBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelFlowOk(ChannelFlowOkBody body, int channelId) throws AMQException;
-    public boolean dispatchChannelOpen(ChannelOpenBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionClose(ConnectionCloseBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionCloseOk(ConnectionCloseOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionOpen(ConnectionOpenBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionSecureOk(ConnectionSecureOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionStartOk(ConnectionStartOkBody body, int channelId) throws AMQException;
-    public boolean dispatchConnectionTuneOk(ConnectionTuneOkBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeBound(ExchangeBoundBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeDeclare(ExchangeDeclareBody body, int channelId) throws AMQException;
-    public boolean dispatchExchangeDelete(ExchangeDeleteBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueBind(QueueBindBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueDeclare(QueueDeclareBody body, int channelId) throws AMQException;
-    public boolean dispatchQueueDelete(QueueDeleteBody body, int channelId) throws AMQException;
-    public boolean dispatchQueuePurge(QueuePurgeBody body, int channelId) throws AMQException;
-    public boolean dispatchTxCommit(TxCommitBody body, int channelId) throws AMQException;
-    public boolean dispatchTxRollback(TxRollbackBody body, int channelId) throws AMQException;
-    public boolean dispatchTxSelect(TxSelectBody body, int channelId) throws AMQException;
+    public boolean dispatchBasicAck(BasicAckBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicCancel(BasicCancelBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicConsume(BasicConsumeBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicGet(BasicGetBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicPublish(BasicPublishBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicQos(BasicQosBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicRecover(BasicRecoverBody body, int channelId) throws QpidException;
+    public boolean dispatchBasicReject(BasicRejectBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelClose(ChannelCloseBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelCloseOk(ChannelCloseOkBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelFlow(ChannelFlowBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelFlowOk(ChannelFlowOkBody body, int channelId) throws QpidException;
+    public boolean dispatchChannelOpen(ChannelOpenBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionClose(ConnectionCloseBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionCloseOk(ConnectionCloseOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionOpen(ConnectionOpenBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionSecureOk(ConnectionSecureOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionStartOk(ConnectionStartOkBody body, int channelId) throws QpidException;
+    public boolean dispatchConnectionTuneOk(ConnectionTuneOkBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeBound(ExchangeBoundBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeDeclare(ExchangeDeclareBody body, int channelId) throws QpidException;
+    public boolean dispatchExchangeDelete(ExchangeDeleteBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueBind(QueueBindBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueDeclare(QueueDeclareBody body, int channelId) throws QpidException;
+    public boolean dispatchQueueDelete(QueueDeleteBody body, int channelId) throws QpidException;
+    public boolean dispatchQueuePurge(QueuePurgeBody body, int channelId) throws QpidException;
+    public boolean dispatchTxCommit(TxCommitBody body, int channelId) throws QpidException;
+    public boolean dispatchTxRollback(TxRollbackBody body, int channelId) throws QpidException;
+    public boolean dispatchTxSelect(TxSelectBody body, int channelId) throws QpidException;
 
-    boolean dispatchQueueUnbind(QueueUnbindBody queueUnbindBody, int channelId) throws AMQException;
+    boolean dispatchQueueUnbind(QueueUnbindBody queueUnbindBody, int channelId) throws QpidException;
 
-    boolean dispatchBasicRecoverSync(BasicRecoverSyncBody basicRecoverSyncBody, int channelId) throws AMQException;
+    boolean dispatchBasicRecoverSync(BasicRecoverSyncBody basicRecoverSyncBody, int channelId) throws QpidException;
 
-    boolean dispatchConfirmSelect(ConfirmSelectBody confirmSelectBody, int channelId) throws AMQException;
+    boolean dispatchConfirmSelect(ConfirmSelectBody confirmSelectBody, int channelId) throws QpidException;
 }

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxCommitBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -67,7 +67,7 @@ public class TxCommitBody extends AMQMet
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxCommit(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxCommitOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxCommitOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -65,7 +65,7 @@ public class TxCommitOkBody extends AMQM
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxCommitOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxRollbackBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -65,7 +65,7 @@ public class TxRollbackBody extends AMQM
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxRollback(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxRollbackOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxRollbackOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -66,7 +66,7 @@ public class TxRollbackOkBody extends AM
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxRollbackOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxSelectBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -68,7 +68,7 @@ public class TxSelectBody extends AMQMet
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxSelect(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectOkBody.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectOkBody.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectOkBody.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/framing/TxSelectOkBody.java Wed Jul  8 13:50:16 2015
@@ -30,7 +30,7 @@ package org.apache.qpid.framing;
 import java.io.DataOutput;
 import java.io.IOException;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 
 public class TxSelectOkBody extends AMQMethodBodyImpl implements EncodableAMQDataBlock, AMQMethodBody
 {
@@ -64,7 +64,7 @@ public class TxSelectOkBody extends AMQM
     {
     }
 
-    public boolean execute(MethodDispatcher dispatcher, int channelId) throws AMQException
+    public boolean execute(MethodDispatcher dispatcher, int channelId) throws QpidException
 	{
         return dispatcher.dispatchTxSelectOk(this, channelId);
 	}

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQMethodListener.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQMethodListener.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQVersionAwareProtocolSession.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQVersionAwareProtocolSession.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.protocol;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.framing.AMQMethodBody;
 import org.apache.qpid.framing.ContentBody;
 import org.apache.qpid.framing.ContentHeaderBody;
@@ -48,10 +48,10 @@ public interface AMQVersionAwareProtocol
     MethodRegistry getMethodRegistry();
 
 
-    public void methodFrameReceived(int channelId, AMQMethodBody body) throws AMQException;
-    public void contentHeaderReceived(int channelId, ContentHeaderBody body) throws AMQException;
-    public void contentBodyReceived(int channelId, ContentBody body) throws AMQException;
-    public void heartbeatBodyReceived(int channelId, HeartbeatBody body) throws AMQException;
+    public void methodFrameReceived(int channelId, AMQMethodBody body) throws QpidException;
+    public void contentHeaderReceived(int channelId, ContentHeaderBody body) throws QpidException;
+    public void contentBodyReceived(int channelId, ContentBody body) throws QpidException;
+    public void heartbeatBodyReceived(int channelId, HeartbeatBody body) throws QpidException;
 
 
     public void setSender(ByteBufferSender sender);

Copied: qpid/java/trunk/common/src/test/java/org/apache/qpid/QpidExceptionTest.java (from r1689639, qpid/java/trunk/common/src/test/java/org/apache/qpid/AMQExceptionTest.java)
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/test/java/org/apache/qpid/QpidExceptionTest.java?p2=qpid/java/trunk/common/src/test/java/org/apache/qpid/QpidExceptionTest.java&p1=qpid/java/trunk/common/src/test/java/org/apache/qpid/AMQExceptionTest.java&r1=1689639&r2=1689876&rev=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQMethodListener.java (original)
+++ qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQMethodListener.java Wed Jul  8 13:50:16 2015
@@ -20,7 +20,7 @@
  */
 package org.apache.qpid.protocol;
 
-import org.apache.qpid.AMQException;
+import org.apache.qpid.QpidException;
 import org.apache.qpid.framing.AMQMethodBody;
 
 /**
@@ -47,12 +47,12 @@ public interface AMQMethodListener
      *         not prohibit the method event being delivered to subsequent listeners but can be used to determine if
      *         nobody has dealt with an incoming method frame.
      *
      * @throws AMQException if an error has occurred. This exception may be delivered to all registered listeners using
      *         the error() method (see below) allowing them to perform cleanup if necessary.
      * <p>
      * TODO Consider narrowing the exception.
      */
-    <B extends AMQMethodBody> boolean methodReceived(AMQMethodEvent<B> evt) throws AMQException;
+    <B extends AMQMethodBody> boolean methodReceived(AMQMethodEvent<B> evt) throws QpidException;
 
     /**
      * Notifies the listener of an error on the event context to which it is listening. The listener should perform
@@ -47,12 +47,12 @@ public interface AMQMethodListener
      *         nobody has dealt with an incoming method frame.
      *
-     * @throws AMQException if an error has occurred. This exception may be delivered to all registered listeners using
+     * @throws QpidException if an error has occurred. This exception may be delivered to all registered listeners using
      *         the error() method (see below) allowing them to perform cleanup if necessary.
      * <p>

Modified: qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQVersionAwareProtocolSession.java
URL: http://svn.apache.org/viewvc/qpid/java/trunk/common/src/main/java/org/apache/qpid/protocol/AMQVersionAwareProtocolSession.java?rev=1689876&r1=1689875&r2=1689876&view=diff
==============================================================================
--- qpid/java/trunk/common/src/test/java/org/apache/qpid/AMQExceptionTest.java (original)
+++ qpid/java/trunk/common/src/test/java/org/apache/qpid/QpidExceptionTest.java Wed Jul  8 13:50:16 2015
@@ -34,18 +34,18 @@ import org.apache.qpid.test.utils.QpidTe
  * Re-throwing a Subclass of AMQException that does not have the default AMQException constructor which will force the
  * creation of an AMQException.
  */
-public class AMQExceptionTest extends QpidTestCase
+public class QpidExceptionTest extends QpidTestCase
 {
     /**
      * Test that an AMQException will be correctly created and rethrown.
      */
     public void testRethrowGeneric()
     {
-        AMQException test = new AMQException(AMQConstant.ACCESS_REFUSED, "refused", new RuntimeException());
+        QpidException test = new QpidException("refused", new RuntimeException());
 
-        AMQException e = reThrowException(test);
+        QpidException e = reThrowException(test);
 
-        assertEquals("Exception not of correct class", AMQException.class, e.getClass());
+        assertEquals("Exception not of correct class", QpidException.class, e.getClass());
 
     }
 
@@ -57,7 +57,7 @@ public class AMQExceptionTest extends Qp
         AMQFrameDecodingException test = new AMQFrameDecodingException(AMQConstant.INTERNAL_ERROR,
                                                                        "Error",
                                                                        new Exception());
-        AMQException e = reThrowException(test);
+        QpidException e = reThrowException(test);
 
         assertEquals("Exception not of correct class", AMQFrameDecodingException.class, e.getClass());
     }
@@ -70,21 +70,23 @@ public class AMQExceptionTest extends Qp
     {
         AMQExceptionSubclass test = new AMQExceptionSubclass("Invalid Argument Exception");
 
-        AMQException e = reThrowException(test);
+        QpidException e = reThrowException(test);
 
-        assertEquals("Exception not of correct class", AMQException.class, e.getClass());
+        assertEquals("Exception not of correct class", QpidException.class, e.getClass());
     }
 
     /**
      * Private method to rethrown and validate the basic values of the rethrown
      * @param test Exception to rethrow
      * @throws AMQException the rethrown exception
      */
-    private AMQException reThrowException(AMQException test)
+    private QpidException reThrowException(QpidException test)
     {
-        AMQException amqe = test.cloneForCurrentThread();
-
-        assertEquals("Error code does not match.", test.getErrorCode(), amqe.getErrorCode());
+        QpidException amqe = test.cloneForCurrentThread();
+        if(test instanceof AMQException)
+        {
+            assertEquals("Error code does not match.", ((AMQException)test).getErrorCode(), ((AMQException)amqe).getErrorCode());
+        }
         assertTrue("Exception message does not start as expected.", amqe.getMessage().startsWith(test.getMessage()));
         assertEquals("Test Exception is not set as the cause", test, amqe.getCause());
         assertEquals("Cause is not correct", test.getCause(), amqe.getCause().getCause());
@@ -107,12 +109,12 @@ public class AMQExceptionTest extends Qp
     /**
      * Private class that extends AMQException but does not have a default exception.
      */
-    private class AMQExceptionSubclass extends AMQException
+    private class AMQExceptionSubclass extends QpidException
     {
 
         public AMQExceptionSubclass(String msg)
         {
-            super(null, msg, null);
+            super(msg, null);
         }
     }
 }



---------------------------------------------------------------------
@@ -70,21 +70,23 @@ public class AMQExceptionTest extends Qp
      * Private method to rethrown and validate the basic values of the rethrown
      * @param test Exception to rethrow
-     * @throws AMQException the rethrown exception
+     * @throws QpidException the rethrown exception
      */
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org